@@ -3,7 +3,7 @@
  *
  * This file is part of abcm2ps.
  *
- * Copyright (C) 1998-2008 Jean-Franois Moine
+ * Copyright (C) 1998-2009 Jean-Franois Moine
  * Adapted from abc2ps, Copyright (C) 1996,1997 Michael Methfessel
  *
  * This program is free software; you can redistribute it and/or modify
@@ -77,10 +77,19 @@ static void init_ps(char *str, int is_epsf)
 				- p_fmt->rightmargin + 20,
 			-bposy);
 		cur_lmarg = p_fmt->leftmargin - 10;
-	} else	fprintf(fout, "%%!PS-Adobe-2.0\n");
+	} else {
+		fprintf(fout, "%%!PS-Adobe-2.0\n");
+		fprintf(fout, "%%%%BoundingBox: 0 0 %.0f %.0f\n",
+			p_fmt->pagewidth,
+			p_fmt->pageheight);
+	}
 	fprintf(fout, "%%%%Title: %s\n", str);
 	time(&ltime);
+#ifndef WIN32
 	strftime(tex_buf, TEX_BUF_SZ, "%b %e, %Y %H:%M", localtime(&ltime));
+#else
+	strftime(tex_buf, TEX_BUF_SZ, "%b %#d, %Y %H:%M", localtime(&ltime));
+#endif
 	fprintf(fout, "%%%%Creator: abcm2ps-" VERSION "\n"
 		"%%%%CreationDate: %s\n", tex_buf);
 	if (!is_epsf)
@@ -552,7 +561,7 @@ void a2b(void)
 
 	l = strlen(mbf);
 	nbuf += l;
-	if (nbuf >= BUFFSZ - 500) {	/* must have place for 1 more line */
+	if (nbuf >= BUFFSZ - BSIZE) {	/* must have room for 1 more line */
 		error(1, 0, "a2b: buffer full, BUFFSZ=%d", BUFFSZ);
 		exit(3);
 	}
@@ -640,14 +649,16 @@ void write_buffer(void)
 				error(1, 0, "Cannot open EPS file '%s'", p);
 			} else {
 				fprintf(fout,
-					"save	%% EPS file '%s'\n"
+					"save\n"
 					"/showpage{}def/setpagedevice{pop}def\n"
-					"%s T\n", 
-					p, &buf[i]);
+					"%s T\n"
+					"%%%%BeginDocument: %s\n",
+					&buf[i], p);
 				while (fgets(line, sizeof line, f))	/* copy the file */
 					fwrite(line, 1, strlen(line), fout);
 				fclose(f);
-				strcpy(line, "restore	% end EPS\n");
+				strcpy(line, "%%EndDocument\n"
+					"restore\n");
 				fwrite(line, 1, strlen(line), fout);
 			}
 		}
