@@ -792,6 +792,8 @@ void interpret_fmt_line(char *w,		/* keyword */
 			return;
 		}
 		if (strcmp(w, "format") == 0) {
+			if (secure)
+				return;
 			if (read_fmt_file(p) < 0)
 				error(1, 0, "No such format file '%s'", p);
 			return;
@@ -1058,7 +1060,12 @@ int read_fmt_file(char *fn)
 {
 	FILE *fp;
 	char line[BSIZE], *p, *q;
+	static int nbfiles;
 
+	if (nbfiles > 3) {
+		error(1, 0, "Too many simultaneous files");
+		return 0;
+	}
 	line[0] = '\001';
 	if ((fp = open_file(fn, "fmt", &line[1])) == 0)
 		return -1;
@@ -1070,6 +1077,7 @@ int read_fmt_file(char *fn)
 		fclose(fp);
 		return 0;
 	}
+	nbfiles++;
 	for (;;) {
 		p = line;
 		if (!fgets(p, sizeof line, fp))
@@ -1103,10 +1111,12 @@ int read_fmt_file(char *fn)
 					continue;
 				if (strcmp(p, "endps") == 0)
 					break;
-				if (!file_initialized)
-					user_ps_add(p);
-				else
-					PUT1("%s\n", p);
+				if (!secure) {
+					if (!file_initialized)
+						user_ps_add(p);
+					else
+						PUT1("%s\n", p);
+				}
 			}
 			continue;
 		}
@@ -1123,6 +1133,7 @@ int read_fmt_file(char *fn)
 		interpret_fmt_line(q, p, 0);
 	}
 	fclose(fp);
+	nbfiles--;
 	return 0;
 }
 
