@@ -1232,14 +1232,23 @@ static void get_info(struct SYMBOL *s,
 		if (s->as.state != ABC_S_HEAD)
 			break;
 		tunenum++;
+		/* information for index */
 		PUT2("%% --- %s (%s) ---\n"
 			"%% --- font ",
 			&info['X' - 'A']->as.text[2],
 			&info['T' - 'A']->as.text[2]);
 		outft = -1;
-		set_font(TITLEFONT);		/* for index */
+		set_font(TITLEFONT);		/* font in coment */
 		outft = -1;
 		PUT0("\n");
+		if (info['T' - 'A']->next != 0) {
+			PUT1("%% --- + (%s) ---\n",
+				&info['T' - 'A']->next->as.text[2]);
+			if (info['T' - 'A']->next->next != 0)
+				PUT1("%% --- + (%s) ---\n",
+					&info['T' - 'A']->next->next->as.text[2]);
+		}
+
 		if (!epsf)
 			bskip(cfmt.topspace);
 		write_heading(t);
@@ -1311,6 +1320,7 @@ static void get_info(struct SYMBOL *s,
 			goto addinfo;
 		default:
 			gen_ly(1);
+			PUT1("%% --- + (%s) ---\n", &s->as.text[2]);
 			write_title(s);
 			bskip(cfmt.musicspace + 0.2 CM);
 			voice_init();
@@ -1661,7 +1671,8 @@ void do_tune(struct abctune *t,
 			    || as->u.eoln.type == 1)	/* if '\' */
 				continue;
 			if (as->u.eoln.type == 0	/* if normal eoln */
-			    && abc2win)
+			 && abc2win
+			 && t->abc_vers < 2)
 				continue;
 			if (curvoice->last_sym != 0)
 				curvoice->last_sym->sflags |= S_EOLN;
@@ -1949,27 +1960,13 @@ static void get_key(struct SYMBOL *s)
 		if (curvoice->last_sym == 0
 		    && curvoice->time == 0) {
 
-			/* if first symbol of the first voice, apply to all voices */
-			if (curvoice == &voice_tb[parsys->top_voice]
-			    && s->as.state == ABC_S_TUNE) {	/* (not embedded) */
-				for (i = MAXVOICE, p_voice = voice_tb;
-				     --i >= 0;
-				     p_voice++) {
-					memcpy(&p_voice->key, &s->as.u.key,
-					       sizeof p_voice->key);
-					p_voice->sfp = s->as.u.key.sf;
-					if (p_voice->key.bagpipe
-					    && p_voice->stem == 0)
-						p_voice->stem = -1;
-				}
-			} else {
-				memcpy(&curvoice->key, &s->as.u.key,
-				       sizeof curvoice->key);
-				curvoice->sfp = s->as.u.key.sf;
-				if (curvoice->key.bagpipe
-				    && curvoice->stem == 0)
-					curvoice->stem = -1;
-			}
+			/* define the starting clef */
+			memcpy(&curvoice->key, &s->as.u.key,
+			       sizeof curvoice->key);
+			curvoice->sfp = s->as.u.key.sf;
+			if (curvoice->key.bagpipe
+			    && curvoice->stem == 0)
+				curvoice->stem = -1;
 			break;
 		}
 		if (curvoice->sfp == s->as.u.key.sf	/* if same key */
@@ -2321,8 +2318,10 @@ static struct abcsym *process_pscomment(struct abcsym *as)
 				}
 				if (*p == '%')
 					continue;	/* skip comment lines */
-				s = (struct SYMBOL *) as;
-				ps_def(s, p);
+				if (!secure) {
+					s = (struct SYMBOL *) as;
+					ps_def(s, p);
+				}
 			}
 			/* not reached */
 		}
@@ -2375,7 +2374,7 @@ static struct abcsym *process_pscomment(struct abcsym *as)
 			char fn[BSIZE], line[BSIZE];
 
 			gen_ly(1);
-			if (cfmt.textoption == T_SKIP)
+			if (secure || cfmt.textoption == T_SKIP)
 				return as;
 			get_str(line, p, BSIZE);
 			if ((fp = open_file(line, "eps", fn)) == 0) {
