@@ -941,12 +941,10 @@ static char buf[STRL1];
 			return p;
 		}
 	}
-	if (q != 0) {
-		strcpy(b, q + 2);
-		b += strlen(q + 2);
-		*b++ = ' ';
-	}
-	strcpy(b, p);
+	if (q != 0)
+		sprintf(b, "%s %.*s", q + 2, (int) (q - p), p);
+	else
+		strcpy(b, p);
 	if (cfmt.titlecaps)
 		cap_str(buf);
 	return buf;
